' Calibration script with diagnostic logging v1.5

d = CreateObject("roDeviceInfo")
SupportsDiagnostics = (d.GetVersionNumber() >= 263713) ' 4.6.33
' Calibration is single-touch only in 4.7.1 to 4.7.85; 4.6 and before don't distinguish.
SupportsMultiTouchCal = (d.GetVersionNumber() <= 263936) or (d.GetVersionNumber() >= 264022)

i = CreateObject("roImagePlayer")
i.SetDefaultMode(3)						' Stretch to fill 
t = CreateObject("roTouchScreen")

p = CreateObject("roMessagePort")
t.SetPort(p)

ok = t.StartCalibration()
if not ok then
    print "Calibration failed or no screen connected"
    i.Hide()
    v = CreateObject("roVideoMode")
    ' Main text centrered vertically, more text below
    ' use region 80% of width and from 70 to 90% height
    width = v.GetSafeWidth()-v.GetSafeX()
    height = v.GetSafeHeight()-v.GetSafeY()
    left = int(width/10)
    right = int(width*9/10)
    top_err = int(height*4/10)
    bottom_err = int(height*6/10)
    top_txt = int(height*7/10)
    bottom_txt = int(height*9/10)
    err_rect = CreateObject("roRectangle", left, top_err, right-left, bottom_err-top_err)
    txt_rect = CreateObject("roRectangle", left, top_txt, right-left, bottom_txt-top_txt)
    err = CreateObject("roTextWidget", err_rect, 2, 2, { Alignment: 1})
    err.SetForegroundColor(&hff0000)
    err.PushString("Calibration error")
    txt = CreateObject("roTextWidget", txt_rect, 4, 2, { Alignment: 1})
    if SupportsMultiTouchCal
        txt.PushString("Check screen is connected.")
    else
        txt.PushString("Check screen is connected; upgrade to 4.7.86 or later for multi-touch screens")
    end if
    err.Show()
    txt.Show()
else
    waitcount=0
    complete=false
    
    ' Make sure we time out even if no events are received.
    ' Otherwise we don't get a report file. (~2 minute timeout)
    while not complete and waitcount < 1200
        msg = wait(100, p)
        if type(msg) = "roTouchCalibrationEvent"
            state = msg.GetInt()
    
            if state = 0 then
                i.DisplayFile("sys:/caltopleft.bmp")
            else if state = 1 then
                i.DisplayFile("sys:/caltopright.bmp")
            else if state = 2 then
                i.DisplayFile("sys:/calbottomright.bmp")
            else if state = 3 then
                i.DisplayFile("sys:/calbottomleft.bmp")
            else
                complete=true
            end if
        else
        	waitcount = waitcount + 1
            if int(waitcount/10) = waitcount/10 then
                print "Calibration running "; int(waitcount/10)
            end if
        end if
    end while
    print "Calibration complete"
    i.DisplayFile("sys:/calcomplete.bmp")
end if

if SupportsDiagnostics
    ' Write diagnostic report even if detection failed
    d=t.GetDiagnosticInfo()
    f=CreateObject("roCreateFile", "sd:cal_log.html")
    if f <> invalid then
        f.SendBlock(d)
        f.Flush()
    else
        print "Unable to write report to SD card, trying temporary storage"
        f=CreateObject("roCreateFile", "tmp:cal_log.html")
        if f <> invalid then
            f.SendBlock(d)
            f.Flush()
        else
            print "Unable to write report to temporary storage"
        end if
    end if
end if

t.SetCursorBitmap("sys:/default-cursor.png", 15, 16)
t.SetResolution(1024, 768)
t.SetCursorPosition(512, 512)
t.EnableCursor(1)

while true
    msg = wait(100, p)
end while

end
