' Capture script with diagnostic logging v1.6

d = CreateObject("roDeviceInfo")
SupportsEventLogging = (d.GetVersionNumber() >= 263964) ' 4.7.28
SupportsMultiTouchDetection = (d.GetVersionNumber() >= 263964) ' 4.7.28
SupportsLoggingDuringCalibration = (d.GetVersionNumber() >= 263713) ' 4.6.33

v = CreateObject("roVideoMode")

t = CreateObject("roTouchScreen")
t.SetResolution(v.GetResX(), v.GetResY())

' Use the full screen for testing, including the unsafe area                                                                  
t.AddRectangleRegion(0, 0, v.GetResX(), v.GetResY(), 100)                                                                     
t.EnableRegion(100, true) 

m = CreateObject("roMessagePort")
t.SetPort(m)

' Main text centrered vertically, more text below
' use region 80% of width and from 70 to 90% height
width = v.GetSafeWidth()-v.GetSafeX()
height = v.GetSafeHeight()-v.GetSafeY()
left = int(width/10)
right = int(width*9/10)
top_title = int(height*2/10)
bottom_title = int(height*4/10)
top_txt = int(height*5/10)
bottom_txt = int(height*6/10)
top_time = int(height*7/10)
bottom_time = int(height*8/10)
title_rect = CreateObject("roRectangle", left, top_title, right-left, bottom_title-top_title)
txt_rect = CreateObject("roRectangle", left, top_txt, right-left, bottom_txt-top_txt)
time_rect = CreateObject("roRectangle", left, top_time, right-left, bottom_time-top_time)
title = CreateObject("roTextWidget", title_rect, 2, 2, { Alignment: 1})
title.SetForegroundColor(&hff00ff00)
title.PushString("Touchscreen Test Tool")
txt = CreateObject("roTextWidget", txt_rect, 2, 2, { Alignment: 1})
txt_msg = "Touch the screen in any touch/gesture sequence"
if SupportsMultiTouchDetection
    if (t.IsMultiTouchPresent())
        txt_msg = txt_msg + chr(13) + "(Multi-touch screen found)"
    end if
end if
txt.PushString(txt_msg)
tmsg = CreateObject("roTextWidget", time_rect, 2, 2, { Alignment: 1})
title.Show()
txt.Show()

if SupportsEventLogging
    ok = t.StartEventLogging()
    if not ok then
        print "Unable to start event logging"
        txt.PushString("Unable to start event logging")
    else
        touches = 0
        time_left = 30
        tmsg.PushString("Time left : " + str(time_left))
        tmsg.Show()

        while time_left > 0
            time_second = 10
            while time_second > 0 
                msg = wait(100, m)
                if type(msg) = "roTouchEvent"
                    touches = touches + 1
                    lastX = msg.GetX()
                    lastY = msg.GetY()
                end if
                time_second = time_second - 1
            end while
     
	    time_left = time_left - 1 
            status$ = "Time left : " + str(time_left)

            if (touches > 0)
                if (touches = 1)
                    status$ = status$ + chr(13) + str(touches) + " touch seen, last at (" +str(lastX) + "," + str(lastY) + ")"
                else
                    status$ = status$ + chr(13) + str(touches) + " touches seen, last at (" +str(lastX) + "," + str(lastY) + ")"
                end if          
            end if   
     
            tmsg.PushString(status$)
        end while
    end if
else
    if SupportsLoggingDuringCalibration
        txt.PushString("Event logging not supported on this software version" + chr(13) + "Use logging calibration script")
    else
        txt.PushString("Event logging not supported on this software version")
    end if
end if

tmsg.PushString("Test complete")
tmsg.Show()

' Write diagnostic report
d=t.GetDiagnosticInfo()
f=CreateObject("roCreateFile", "sd:touchlog.html")
if f <> invalid then
    f.SendBlock(d)
    f.Flush()
else
    print "Unable to write report to SD card, trying temporary storage"
    f=CreateObject("roCreateFile", "tmp:touchlog.html")
    if f <> invalid then
        f.SendBlock(d)
        f.Flush()
    else
        print "Unable to write report to temporary storage"
    end if
end if

if SupportsEventLogging
    t.StopEventLogging()
end if

t.SetCursorBitmap("sys:/default-cursor.png", 15, 16)
t.SetCursorPosition(v.GetResX() / 2, v.GetResY() / 2)
t.EnableCursor(1)

while true
    msg = wait(100, m)
end while

end
